==> klogshow_1.0.3.orig.tar.gz: klogshow-1.0.3/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   pinon.pierre@gmail.com                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mainObj.h"

int main ( int argc, char *argv[] )
{
	QString		appFileName;
	bool			startByApp = false;
	QString		confFileName = CONF_PATH;

	QApplication	app ( argc, argv );

	app.setQuitOnLastWindowClosed(false);
	
	//Gestion des parametres
	QStringList args = app.arguments();
	
	for ( int i = 0; i < args.size(); i++ )
	{
		if ( i == 0 )
			appFileName = args.at ( i );
		if ( args.at ( i ) == PARAM_START_BY_APP )
			startByApp = true;
		if ( args.at ( i ).startsWith ( PARAM_CONF_FILENAME ) )
			confFileName = args.at ( i ).right ( args.at ( i ).size() - QString ( PARAM_CONF_FILENAME ).size() );
	}
	
	mainObj obj ( appFileName, confFileName, startByApp );
	return ( app.exec() );
}

==> klogshow_1.0.4.orig.tar.gz: klogshow-1.0.4/src/main.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   xes@xesnet.fr                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "mainObj.h"

int main ( int argc, char *argv[] )
{
	QString		appFileName;
	bool			startByApp = false;
	QString		confFileName = CONF_PATH;

	QApplication	app ( argc, argv );

	app.setQuitOnLastWindowClosed(false);
	
	//Gestion des parametres
	QStringList args = app.arguments();
	
	for ( int i = 0; i < args.size(); i++ )
	{
		if ( i == 0 )
			appFileName = args.at ( i );
		if ( args.at ( i ) == PARAM_START_BY_APP )
			startByApp = true;
		if ( args.at ( i ).startsWith ( PARAM_CONF_FILENAME ) )
			confFileName = args.at ( i ).right ( args.at ( i ).size() - QString ( PARAM_CONF_FILENAME ).size() );
	}
	
	//Redemarre l'application en root si necessaire !
#ifdef __linux__
	if ( startByApp == false )
	{
		QSettings settings ( confFileName, QSettings::IniFormat );
		if ( settings.value ( "root", DEFAULT_ROOT ).toBool() )
		{
			QStringList args;
			args << appFileName << "--" << PARAM_START_BY_APP << ( PARAM_CONF_FILENAME + confFileName );
			if ( QProcess::execute ( settings.value ( "appsu", DEFAULT_APPSU ).toString(), args ) == 255 )
				QMessageBox::critical ( 0, settings.value ( "appsu", DEFAULT_APPSU ).toString(), (QString)DEFAULT_APPSU + QObject::tr(" : Command not found !") );
			else
				exit ( 1 );
		}
	}
#endif
	
	mainObj obj ( confFileName );
	return ( app.exec() );
}
